Package: cognitoR
Type: Package
Title: Authentication for 'Shiny' Apps with 'Amazon Cognito'
Version: 1.0.5
Authors@R: c(
    person("Pablo", "Pagnone", role = c("aut", "cre"), email = "pablodp84@gmail.com"),
    person("Aleksander", "Dietrichson", role = c("aut"), email = "dietrichson@gmail.com")
    )
Description: Provides authentication for Shiny applications using 'Amazon Cognito' ( <https://aws.amazon.com/es/cognito/>).
Imports: shiny, config, shinyjs, httr, dplyr, base64enc, jsonlite, paws
License: GPL-3
BugReports: https://github.com/chi2labs/cognitoR/issues
Encoding: UTF-8
RoxygenNote: 7.2.3
Suggests: knitr, rmarkdown
VignetteBuilder: knitr
NeedsCompilation: no
Packaged: 2024-01-29 15:51:31 UTC; r227303
Author: Pablo Pagnone [aut, cre],
  Aleksander Dietrichson [aut]
Maintainer: Pablo Pagnone <pablodp84@gmail.com>
Repository: CRAN
Date/Publication: 2024-01-30 16:10:02 UTC
Built: R 4.6.0; ; 2026-04-25 12:51:16 UTC; unix
